# PyRolL Integral Thermal Model

Plugin for PyRolL providing an integral approach for thermal modelling.

## Documentation

See the [documentation](https://pyroll-project.github.io/modules/pyroll-integral-thermal/docs/docs) to learn about basic
concepts and usage.

## License

The project is licensed under the [BSD 3-Clause license](LICENSE).

## Installation

The package is available via [PyPi](https://pypi.org/project/pyroll-integral-thermal/) and can be installed with
    
    pip install pyroll-integral-thermal